summaryrefslogtreecommitdiffstats
path: root/kommander/editor/command.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-16 19:02:47 +0000
commite985f7e545f4739493965aad69bbecb136dc9346 (patch)
tree54afd409d8acd6202dd8ab611d24e78c28e4c0a0 /kommander/editor/command.h
parentf7670c198945adc3b95ad69a959fe5f8ae55b493 (diff)
downloadtdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.tar.gz
tdewebdev-e985f7e545f4739493965aad69bbecb136dc9346.zip
TQt4 port kdewebdev
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdewebdev@1237029 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kommander/editor/command.h')
-rw-r--r--kommander/editor/command.h81
1 files changed, 41 insertions, 40 deletions
diff --git a/kommander/editor/command.h b/kommander/editor/command.h
index a2162dca..3fd83e1c 100644
--- a/kommander/editor/command.h
+++ b/kommander/editor/command.h
@@ -1,7 +1,7 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -44,13 +44,13 @@ class TQIconView;
class TQMultiLineEdit;
class TQTable;
class TQAction;
-class QDesignerToolBar;
+class TQDesignerToolBar;
class TQMainWindow;
-class QDesignerPopupMenu;
-class QDesignerMenuBar;
+class TQDesignerPopupMenu;
+class TQDesignerMenuBar;
class TQToolBox;
-class Command : public Qt
+class Command : public TQt
{
public:
Command( const TQString &n, FormWindow *fw );
@@ -120,9 +120,10 @@ private:
};
-class CommandHistory : public QObject
+class CommandHistory : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
CommandHistory( int s );
@@ -180,7 +181,7 @@ public:
private:
TQWidget *widget;
- TQRect geometry;
+ TQRect tqgeometry;
};
@@ -254,7 +255,7 @@ class LayoutHorizontalCommand : public Command
{
public:
LayoutHorizontalCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -262,7 +263,7 @@ public:
Type type() const { return LayoutHorizontal; }
private:
- HorizontalLayout layout;
+ HorizontalLayout tqlayout;
};
@@ -270,7 +271,7 @@ class LayoutHorizontalSplitCommand : public Command
{
public:
LayoutHorizontalSplitCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -278,7 +279,7 @@ public:
Type type() const { return LayoutHorizontalSplitter; }
private:
- HorizontalLayout layout;
+ HorizontalLayout tqlayout;
};
@@ -286,7 +287,7 @@ class LayoutVerticalCommand : public Command
{
public:
LayoutVerticalCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -294,7 +295,7 @@ public:
Type type() const { return LayoutVertical; }
private:
- VerticalLayout layout;
+ VerticalLayout tqlayout;
};
@@ -302,7 +303,7 @@ class LayoutVerticalSplitCommand : public Command
{
public:
LayoutVerticalSplitCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl );
void execute();
@@ -310,7 +311,7 @@ public:
Type type() const { return LayoutVerticalSplitter; }
private:
- VerticalLayout layout;
+ VerticalLayout tqlayout;
};
@@ -318,7 +319,7 @@ class LayoutGridCommand : public Command
{
public:
LayoutGridCommand( const TQString &n, FormWindow *fw,
- TQWidget *parent, TQWidget *layoutBase,
+ TQWidget *tqparent, TQWidget *tqlayoutBase,
const TQWidgetList &wl, int xres, int yres );
void execute();
@@ -326,7 +327,7 @@ public:
Type type() const { return LayoutGrid; }
private:
- GridLayout layout;
+ GridLayout tqlayout;
};
@@ -334,14 +335,14 @@ class BreakLayoutCommand : public Command
{
public:
BreakLayoutCommand( const TQString &n, FormWindow *fw,
- TQWidget *layoutBase, const TQWidgetList &wl );
+ TQWidget *tqlayoutBase, const TQWidgetList &wl );
void execute();
void unexecute();
Type type() const { return BreakLayout; }
private:
- Layout *layout;
+ Layout *tqlayout;
int spacing;
int margin;
TQWidget *lb;
@@ -658,7 +659,7 @@ public:
{
TQString text;
TQPixmap pix;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
bool operator==( const Item & ) const { return FALSE; }
#endif
};
@@ -684,7 +685,7 @@ public:
{
TQString text;
TQPixmap pix;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
bool operator==( const Item & ) const { return FALSE; }
#endif
};
@@ -744,7 +745,7 @@ public:
{
TQString text;
TQPixmap pix;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
bool operator==( const Row& ) const { return FALSE; }
#endif
};
@@ -754,7 +755,7 @@ public:
TQString text;
TQPixmap pix;
TQString field;
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
bool operator==( const Column& ) const { return FALSE; }
#endif
};
@@ -778,7 +779,7 @@ class AddActionToToolBarCommand : public Command
{
public:
AddActionToToolBarCommand( const TQString &n, FormWindow *fw,
- TQAction *a, QDesignerToolBar *tb, int idx );
+ TQAction *a, TQDesignerToolBar *tb, int idx );
void execute();
void unexecute();
@@ -786,7 +787,7 @@ public:
private:
TQAction *action;
- QDesignerToolBar *toolBar;
+ TQDesignerToolBar *toolBar;
int index;
};
@@ -795,7 +796,7 @@ class RemoveActionFromToolBarCommand : public AddActionToToolBarCommand
{
public:
RemoveActionFromToolBarCommand( const TQString &n, FormWindow *fw,
- TQAction *a, QDesignerToolBar *tb, int idx )
+ TQAction *a, TQDesignerToolBar *tb, int idx )
: AddActionToToolBarCommand( n, fw, a, tb, idx ) {}
void execute() { AddActionToToolBarCommand::unexecute(); }
@@ -808,7 +809,7 @@ class AddActionToPopupCommand : public Command
{
public:
AddActionToPopupCommand( const TQString &n, FormWindow *fw,
- TQAction *a, QDesignerPopupMenu *p, int idx );
+ TQAction *a, TQDesignerPopupMenu *p, int idx );
void execute();
void unexecute();
@@ -816,7 +817,7 @@ public:
private:
TQAction *action;
- QDesignerPopupMenu *popup;
+ TQDesignerPopupMenu *popup;
int index;
};
@@ -825,7 +826,7 @@ class RemoveActionFromPopupCommand : public AddActionToPopupCommand
{
public:
RemoveActionFromPopupCommand( const TQString &n, FormWindow *fw,
- TQAction *a, QDesignerPopupMenu *p, int idx )
+ TQAction *a, TQDesignerPopupMenu *p, int idx )
: AddActionToPopupCommand( n, fw, a, p, idx ) {}
void execute() { AddActionToPopupCommand::unexecute(); }
@@ -844,8 +845,8 @@ public:
Type type() const { return AddMenu; }
protected:
- QDesignerMenuBar *menuBar;
- QDesignerPopupMenu *popup;
+ TQDesignerMenuBar *menuBar;
+ TQDesignerPopupMenu *popup;
TQMainWindow *mainWindow;
int id;
int index;
@@ -857,7 +858,7 @@ class RemoveMenuCommand : public AddMenuCommand
{
public:
RemoveMenuCommand( const TQString &n, FormWindow *fw, TQMainWindow *mw,
- QDesignerMenuBar *mb, QDesignerPopupMenu *p, int i, int idx, const TQString &mn )
+ TQDesignerMenuBar *mb, TQDesignerPopupMenu *p, int i, int idx, const TQString &mn )
: AddMenuCommand( n, fw, mw ) { menuBar = mb; popup = p; id = i; index = idx, name = mn; }
void execute() { AddMenuCommand::unexecute(); }
@@ -869,7 +870,7 @@ public:
class RenameMenuCommand : public Command
{
public:
- RenameMenuCommand( const TQString &n, FormWindow *fw, QDesignerMenuBar *mb,
+ RenameMenuCommand( const TQString &n, FormWindow *fw, TQDesignerMenuBar *mb,
int i, const TQString &on, const TQString &nn );
void execute();
@@ -877,7 +878,7 @@ public:
Type type() const { return RenameMenu; }
private:
- QDesignerMenuBar *menuBar;
+ TQDesignerMenuBar *menuBar;
int id;
TQString oldName, newName;
@@ -886,16 +887,16 @@ private:
class MoveMenuCommand : public Command
{
public:
- MoveMenuCommand( const TQString &n, FormWindow *fw, QDesignerMenuBar *mb,
- QDesignerPopupMenu *p, int fidx, int tidx, const TQString &txt );
+ MoveMenuCommand( const TQString &n, FormWindow *fw, TQDesignerMenuBar *mb,
+ TQDesignerPopupMenu *p, int fidx, int tidx, const TQString &txt );
void execute();
void unexecute();
Type type() const { return MoveMenu; }
private:
- QDesignerMenuBar *menuBar;
- QDesignerPopupMenu *popup;
+ TQDesignerMenuBar *menuBar;
+ TQDesignerPopupMenu *popup;
int fromIdx, toIdx;
TQString text;
@@ -911,7 +912,7 @@ public:
Type type() const { return AddToolBar; }
protected:
- QDesignerToolBar *toolBar;
+ TQDesignerToolBar *toolBar;
TQMainWindow *mainWindow;
};
@@ -919,7 +920,7 @@ protected:
class RemoveToolBarCommand : public AddToolBarCommand
{
public:
- RemoveToolBarCommand( const TQString &n, FormWindow *fw, TQMainWindow *mw, QDesignerToolBar *tb )
+ RemoveToolBarCommand( const TQString &n, FormWindow *fw, TQMainWindow *mw, TQDesignerToolBar *tb )
: AddToolBarCommand( n, fw, mw ) { toolBar = tb; }
void execute() { AddToolBarCommand::unexecute(); }
@@ -1,7 +1,7 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the